@@ -112,6 +112,20 @@ static const GOptionEntry options[] = {
 /* -- app menu -- */
 
 
+static void
+activate_new (GSimpleAction *action,
+              GVariant      *parameter,
+              gpointer       user_data)
+{
+	GApplication *application = user_data;
+	GList        *windows;
+
+	windows = gtk_application_get_windows (GTK_APPLICATION (application));
+	if (windows != NULL)
+		activate_action_new (NULL, windows->data);
+}
+
+
 static void
 activate_help (GSimpleAction *action,
                GVariant      *parameter,
@@ -150,6 +164,7 @@ activate_quit (GSimpleAction *action,
 
 
 static const GActionEntry app_menu_entries[] = {
+	{ "new",  activate_new },
 	{ "help",  activate_help },
 	{ "about", activate_about },
 	{ "quit",  activate_quit }
@@ -363,9 +378,6 @@ handle_method_call (GDBusConnection       *connection,
 				g_variant_builder_add (&builder, "{ss}",
 						       "default-extension",
 						       mime_type_desc[supported_types[i]].default_ext);
-				g_variant_builder_add (&builder, "{ss}",
-						       "description",
-						       _(mime_type_desc[supported_types[i]].name));
 				g_variant_builder_close (&builder);
 			}
 			g_variant_builder_close (&builder);
